@@ -79,12 +79,16 @@ class UAClientBehaveConfig:
         "destroy_instances",
         "ephemeral_instance",
         "snapshot_strategy",
+        "sbuild_output_to_terminal",
     ]
     str_options = [
         "cloud_credentials_path",
         "contract_token",
         "contract_token_staging",
         "contract_token_staging_expired",
+        "landscape_registration_key",
+        "landscape_api_access_key",
+        "landscape_api_secret_key",
         "machine_type",
         "private_key_file",
         "private_key_name",
@@ -101,6 +105,9 @@ class UAClientBehaveConfig:
         "contract_token",
         "contract_token_staging",
         "contract_token_staging_expired",
+        "landscape_registration_key",
+        "landscape_api_access_key",
+        "landscape_api_secret_key",
     ]
 
     # This variable is used in .from_environ() but also to emit the "Config
@@ -115,6 +122,7 @@ class UAClientBehaveConfig:
         destroy_instances: bool = True,
         ephemeral_instance: bool = False,
         snapshot_strategy: bool = False,
+        sbuild_output_to_terminal: bool = False,
         machine_type: str = "lxd-container",
         private_key_file: Optional[str] = None,
         private_key_name: str = "uaclient-integration",
@@ -122,6 +130,9 @@ class UAClientBehaveConfig:
         contract_token: Optional[str] = None,
         contract_token_staging: Optional[str] = None,
         contract_token_staging_expired: Optional[str] = None,
+        landscape_registration_key: Optional[str] = None,
+        landscape_api_access_key: Optional[str] = None,
+        landscape_api_secret_key: Optional[str] = None,
         artifact_dir: str = "artifacts",
         install_from: InstallationSource = InstallationSource.LOCAL,
         custom_ppa: Optional[str] = None,
@@ -135,9 +146,13 @@ class UAClientBehaveConfig:
         self.cloud_credentials_path = cloud_credentials_path
         self.ephemeral_instance = ephemeral_instance
         self.snapshot_strategy = snapshot_strategy
+        self.sbuild_output_to_terminal = sbuild_output_to_terminal
         self.contract_token = contract_token
         self.contract_token_staging = contract_token_staging
         self.contract_token_staging_expired = contract_token_staging_expired
+        self.landscape_registration_key = landscape_registration_key
+        self.landscape_api_access_key = landscape_api_access_key
+        self.landscape_api_secret_key = landscape_api_secret_key
         self.image_clean = image_clean
         self.destroy_instances = destroy_instances
         self.machine_type = machine_type
@@ -282,17 +297,17 @@ class UAClientBehaveConfig:
                 continue
             kwargs[our_key] = value
 
+        # userdata should override environment variables
+        kwargs.update(config.userdata)
+
         # Next, sanitise the non-string options to Python types
         for key in cls.boolean_options:
             bool_value = True  # Default to True
             if key in kwargs:
-                if kwargs[key] == "0":
+                if kwargs[key] == "0" or str(kwargs[key]).lower() == "false":
                     bool_value = False
                 kwargs[key] = bool_value
 
-        # userdata should override environment variables
-        kwargs.update(config.userdata)
-
         if "install_from" in kwargs:
             kwargs["install_from"] = InstallationSource(kwargs["install_from"])
 
@@ -452,7 +467,7 @@ def before_scenario(context: Context, scenario: Scenario):
     for step in scenario.steps:
         if step.text:
             step.text = process_template_vars(
-                context, step.text, logger_fn=logger.warn
+                context, step.text, logger_fn=logger.warn, shown=True
             )
 
 
@@ -524,9 +539,11 @@ def after_all(context):
 
     if context.pro_config.destroy_instances:
         try:
-            key_pair = context.pro_config.default_cloud.api.key_pair
-            os.remove(key_pair.private_key_path)
-            os.remove(key_pair.public_key_path)
+            if context.pro_config.default_cloud._ssh_key_managed:
+                key_pair = context.pro_config.default_cloud.api.key_pair
+                os.remove(key_pair.private_key_path)
+                os.remove(key_pair.public_key_path)
+
         except Exception as e:
             logging.error(
                 "Failed to delete instance ssh keys:\n{}".format(str(e))
