@@ -5,12 +5,15 @@ import os
 import re
 import shutil
 import subprocess
+import sys
 import tempfile
 from enum import Enum
 from typing import Callable, Iterable, List, Optional
 
 import yaml
 
+from uaclient.system import get_dpkg_arch
+
 SUT = "system-under-test"
 LXC_PROPERTY_MAP = {
     "image": {"series": "properties.release", "machine_type": "Type"},
@@ -88,6 +91,7 @@ def repo_state_hash(
         "tools",
         "docs",
         "dev-docs",
+        "keyrings",
     )
 ):
     """
@@ -148,7 +152,20 @@ def repo_state_hash(
     return hashlib.md5(output_to_hash).hexdigest()
 
 
-def build_debs(series: str, chroot: Optional[str] = None) -> List[str]:
+def get_debs_for_series(debs_path: str, series: str) -> List[str]:
+    return [
+        os.path.join(debs_path, deb_file)
+        for deb_file in os.listdir(debs_path)
+        if series in deb_file
+    ]
+
+
+def build_debs(
+    series: str,
+    architecture: Optional[str] = None,
+    chroot: Optional[str] = None,
+    sbuild_output_to_terminal: bool = False,
+) -> List[str]:
     """
     Build the package through sbuild and store the debs into
     output_deb_dir
@@ -158,7 +175,10 @@ def build_debs(series: str, chroot: Optional[str] = None) -> List[str]:
 
     :return: A list of file paths to debs created by the build.
     """
-    deb_prefix = "{}-{}-".format(series, repo_state_hash())
+    if architecture is None:
+        architecture = get_dpkg_arch()
+
+    deb_prefix = "{}-{}-{}-".format(series, architecture, repo_state_hash())
     tools_deb_name = "{}ubuntu-advantage-tools.deb".format(deb_prefix)
     pro_deb_name = "{}ubuntu-advantage-pro.deb".format(deb_prefix)
     tools_deb_cache_path = os.path.join(UA_DEB_BUILD_CACHE, tools_deb_name)
@@ -219,16 +239,15 @@ def build_debs(series: str, chroot: Optional[str] = None) -> List[str]:
         shutil.rmtree(SBUILD_DIR)
     os.makedirs(SBUILD_DIR)
 
-    curr_dir = os.getcwd()
-    os.chdir(SBUILD_DIR)
-
     sbuild_cmd = [
         "sbuild",
         "--no-run-lintian",
         "--resolve-alternatives",
         "--no-clean-source",
+        "--build-dir",
+        SBUILD_DIR,
         "--arch",
-        "amd64",
+        architecture,
         "-d",
         series,
         SOURCE_PR_UNTAR_DIR,
@@ -237,7 +256,7 @@ def build_debs(series: str, chroot: Optional[str] = None) -> List[str]:
         sbuild_cmd += ["--chroot", chroot]
     else:
         # use ua-series-arch chroot if present
-        ua_chroot = "ua-{}-amd64".format(series)
+        ua_chroot = "ua-{}-{}".format(series, architecture)
         proc = subprocess.run(
             ["schroot", "--info", "--chroot", ua_chroot],
             stdout=subprocess.DEVNULL,
@@ -251,15 +270,17 @@ def build_debs(series: str, chroot: Optional[str] = None) -> List[str]:
     env["DEB_BUILD_OPTIONS"] = env.get("DEB_BUILD_OPTIONS", "") + " nocheck"
 
     logging.info('--- Running "{}"'.format(" ".join(sbuild_cmd)))
+    sbuild_out = subprocess.DEVNULL  # type: Optional[int]
+    if sbuild_output_to_terminal:
+        sbuild_out = sys.stderr.fileno()
     subprocess.run(
         sbuild_cmd,
         env=env,
-        stdout=subprocess.DEVNULL,
-        stderr=subprocess.DEVNULL,
+        stdout=sbuild_out,
+        stderr=sbuild_out,
         check=True,
     )
     logging.info("--- Successfully ran sbuild")
-    os.chdir(curr_dir)
 
     for f in os.listdir(SBUILD_DIR):
         if f.endswith(".deb"):
@@ -287,7 +308,7 @@ def _replace_and_log(s, old, new, logger_fn):
 
 
 def process_template_vars(
-    context, template: str, logger_fn: Optional[Callable] = None
+    context, template: str, logger_fn: Optional[Callable] = None, shown=False
 ) -> str:
     if logger_fn is None:
         logger_fn = logging.info
@@ -313,6 +334,14 @@ def process_template_vars(
                     context.machines[args[1]].instance.ip,
                     logger_fn,
                 )
+        elif function_name == "machine-name":
+            if args[1] in context.machines:
+                processed_template = _replace_and_log(
+                    processed_template,
+                    match.group(0),
+                    context.machines[args[1]].instance.name,
+                    logger_fn,
+                )
         elif function_name == "cloud":
             processed_template = _replace_and_log(
                 processed_template,
@@ -339,6 +368,22 @@ def process_template_vars(
                 context.pro_config.contract_token_staging,
                 logger_fn,
             )
+        elif function_name == "contract_token":
+            processed_template = _replace_and_log(
+                processed_template,
+                match.group(0),
+                context.pro_config.contract_token,
+                logger_fn,
+            )
+        elif function_name == "config":
+            item = args[1]
+            if not shown or item not in context.pro_config.redact_options:
+                processed_template = _replace_and_log(
+                    processed_template,
+                    match.group(0),
+                    getattr(context.pro_config, item),
+                    logger_fn,
+                )
         elif function_name == "stored_var":
             if context.stored_vars.get(args[1]):
                 processed_template = _replace_and_log(
