@@ -6,7 +6,7 @@ from typing import Any, Dict, Optional, Tuple
 import mock
 import pytest
 
-from uaclient import messages, system, util
+from uaclient import exceptions, messages, system, util
 from uaclient.entitlements import base
 from uaclient.entitlements.entitlement_status import (
     ApplicabilityStatus,
@@ -246,10 +246,10 @@ class TestUaEntitlementCanEnable:
         )
 
     @pytest.mark.parametrize("caplog_text", [logging.DEBUG], indirect=True)
-    @mock.patch("uaclient.contract.request_updated_contract")
+    @mock.patch("uaclient.contract.refresh")
     def test_can_enable_updates_expired_contract(
         self,
-        m_request_updated_contract,
+        m_refresh,
         caplog_text,
         concrete_entitlement_factory,
     ):
@@ -260,9 +260,7 @@ class TestUaEntitlementCanEnable:
         with mock.patch.object(ent, "is_access_expired", return_value=True):
             assert not ent.can_enable()[0]
 
-        assert [
-            mock.call(ent.cfg)
-        ] == m_request_updated_contract.call_args_list
+        assert [mock.call(ent.cfg)] == m_refresh.call_args_list
         assert (
             "Updating contract on service 'testconcreteentitlement' expiry"
             in caplog_text()
@@ -1227,3 +1225,216 @@ class TestGetContractVariant:
 
         assert expected_contract_variants == actual_contract_variants
         assert 1 == m_base_ent_cfg.call_count
+
+
+class TestHandleRequiredSnaps:
+    @pytest.mark.parametrize(
+        "entitlement_cfg",
+        (
+            ({}),
+            (
+                {
+                    "entitlement": {
+                        "directives": {
+                            "requiredSnaps": [
+                                {"name": "test1", "channel": "latest/stable"},
+                                {
+                                    "name": "test2",
+                                    "classicConfinementSupport": True,
+                                },
+                                {"name": "test3"},
+                            ]
+                        },
+                    }
+                }
+            ),
+        ),
+    )
+    @mock.patch(
+        "uaclient.entitlements.base.UAEntitlement._base_entitlement_cfg"
+    )
+    @mock.patch("uaclient.snap.is_snapd_installed", return_value=True)
+    @mock.patch("uaclient.snap.run_snapd_wait_cmd")
+    @mock.patch("uaclient.snap.get_snap_info")
+    @mock.patch("uaclient.snap.install_snap")
+    @mock.patch("uaclient.http.validate_proxy")
+    @mock.patch("uaclient.snap.configure_snap_proxy")
+    def test_handle_required_snaps(
+        self,
+        m_configure_snap_proxy,
+        m_validate_proxy,
+        m_install_snap,
+        m_get_snap_info,
+        m_run_snapd_wait_cmd,
+        m_is_snapd_installed,
+        m_base_ent_cfg,
+        entitlement_cfg,
+        concrete_entitlement_factory,
+    ):
+        entitlement = concrete_entitlement_factory()
+        m_base_ent_cfg.return_value = entitlement_cfg
+        m_get_snap_info.side_effect = [
+            exceptions.SnapNotInstalledError("snap"),
+            exceptions.SnapNotInstalledError("snap"),
+            mock.MagicMock,
+        ]
+
+        assert entitlement.handle_required_snaps()
+
+        if not entitlement_cfg:
+            assert 0 == m_is_snapd_installed.call_count
+            assert 0 == m_run_snapd_wait_cmd.call_count
+            assert 0 == m_validate_proxy.call_count
+            assert 0 == m_configure_snap_proxy.call_count
+        else:
+            assert 1 == m_is_snapd_installed.call_count
+            assert 1 == m_run_snapd_wait_cmd.call_count
+            assert 2 == m_validate_proxy.call_count
+            assert 1 == m_configure_snap_proxy.call_count
+            assert [
+                mock.call(
+                    "test1",
+                    channel="latest/stable",
+                    classic_confinement_support=False,
+                ),
+                mock.call(
+                    "test2", channel=None, classic_confinement_support=True
+                ),
+            ] == m_install_snap.call_args_list
+
+
+class TestHandleRequiredPackages:
+    @pytest.mark.parametrize(
+        [
+            "required_packages_directive",
+            "expected_apt_update_calls",
+            "expected_apt_install_calls",
+            "expected_result",
+        ],
+        [
+            (
+                None,
+                [],
+                [],
+                True,
+            ),
+            (
+                [],
+                [],
+                [],
+                True,
+            ),
+            (
+                [{"name": "package"}],
+                [mock.call()],
+                [mock.call(["package"])],
+                True,
+            ),
+            (
+                [{"name": "package"}, {"name": "package2"}],
+                [mock.call()],
+                [mock.call(["package", "package2"])],
+                True,
+            ),
+        ],
+    )
+    @mock.patch("uaclient.apt.run_apt_install_command")
+    @mock.patch("uaclient.apt.run_apt_update_command")
+    @mock.patch(
+        "uaclient.entitlements.base.UAEntitlement.entitlement_cfg",
+        new_callable=mock.PropertyMock,
+    )
+    def test_handle_required_packages(
+        self,
+        m_entitlement_cfg,
+        m_apt_update,
+        m_apt_install,
+        required_packages_directive,
+        expected_apt_update_calls,
+        expected_apt_install_calls,
+        expected_result,
+        concrete_entitlement_factory,
+    ):
+        entitlement = concrete_entitlement_factory()
+        m_entitlement_cfg.return_value = {
+            "entitlement": {
+                "directives": {"requiredPackages": required_packages_directive}
+            }
+        }
+
+        assert expected_result == entitlement.handle_required_packages()
+        assert expected_apt_update_calls == m_apt_update.call_args_list
+        assert expected_apt_install_calls == m_apt_install.call_args_list
+
+    @pytest.mark.parametrize(
+        [
+            "required_packages_directive",
+            "expected_apt_remove_calls",
+            "expected_result",
+        ],
+        [
+            (
+                None,
+                [],
+                True,
+            ),
+            (
+                [],
+                [],
+                True,
+            ),
+            (
+                [{"name": "package"}],
+                [mock.call([], mock.ANY)],
+                True,
+            ),
+            (
+                [{"name": "package"}, {"name": "package2"}],
+                [mock.call([], mock.ANY)],
+                True,
+            ),
+            (
+                [
+                    {"name": "package"},
+                    {"name": "package2", "removeOnDisable": True},
+                ],
+                [mock.call(["package2"], mock.ANY)],
+                True,
+            ),
+            (
+                [
+                    {"name": "package"},
+                    {"name": "package2", "removeOnDisable": True},
+                    {"name": "package3", "removeOnDisable": False},
+                    {"name": "package4", "removeOnDisable": True},
+                ],
+                [mock.call(["package2", "package4"], mock.ANY)],
+                True,
+            ),
+        ],
+    )
+    @mock.patch("uaclient.apt.remove_packages")
+    @mock.patch(
+        "uaclient.entitlements.base.UAEntitlement.entitlement_cfg",
+        new_callable=mock.PropertyMock,
+    )
+    def test_handle_removing_required_packages(
+        self,
+        m_entitlement_cfg,
+        m_apt_remove,
+        required_packages_directive,
+        expected_apt_remove_calls,
+        expected_result,
+        concrete_entitlement_factory,
+    ):
+        entitlement = concrete_entitlement_factory()
+        m_entitlement_cfg.return_value = {
+            "entitlement": {
+                "directives": {"requiredPackages": required_packages_directive}
+            }
+        }
+
+        assert (
+            expected_result == entitlement.handle_removing_required_packages()
+        )
+        assert expected_apt_remove_calls == m_apt_remove.call_args_list
