@@ -5,7 +5,6 @@ import pytest
 
 from uaclient import apt, messages, system
 from uaclient.entitlements.cis import CIS_DOCS_URL, CISEntitlement
-from uaclient.entitlements.entitlement_status import ApplicationStatus
 
 M_REPOPATH = "uaclient.entitlements.repo."
 
@@ -20,21 +19,6 @@ def entitlement(entitlement_factory):
     )
 
 
-class TestCISEntitlementCanEnable:
-    def test_can_enable_true_on_entitlement_inactive(
-        self, capsys, entitlement
-    ):
-        """When entitlement is INACTIVE, can_enable returns True."""
-        # Unset static affordance container check
-        with mock.patch.object(
-            entitlement,
-            "application_status",
-            return_value=(ApplicationStatus.DISABLED, ""),
-        ):
-            assert entitlement.can_enable()
-        assert ("", "") == capsys.readouterr()
-
-
 class TestCISEntitlementEnable:
     @mock.patch("uaclient.apt.get_apt_cache_policy")
     @mock.patch("uaclient.apt.setup_apt_proxy")
@@ -88,7 +72,7 @@ class TestCISEntitlementEnable:
         add_apt_calls = [
             mock.call(
                 "/etc/apt/sources.list.d/ubuntu-cis.list",
-                "http://CIS",
+                "http://CIS/ubuntu",
                 "{}-token".format(entitlement.name),
                 ["xenial"],
                 entitlement.repo_key_file,
