@@ -2,14 +2,13 @@ import copy
 import datetime
 import itertools
 import json
-import logging
 import os
 import stat
 
 import mock
 import pytest
 
-from uaclient import apt, exceptions, messages, util
+from uaclient import apt, exceptions, http, messages
 from uaclient.config import (
     PRIVATE_SUBDIR,
     UA_CONFIGURABLE_KEYS,
@@ -649,7 +648,7 @@ class TestDeleteCache:
 
 class TestProcessConfig:
     @pytest.mark.parametrize(
-        "http_proxy, https_proxy, snap_is_installed, snap_http_val, "
+        "http_proxy, https_proxy, snap_is_snapd_installed, snap_http_val, "
         "snap_https_val, livepatch_enabled, livepatch_http_val, "
         "livepatch_https_val, snap_livepatch_msg, "
         "global_https, global_http, ua_https, ua_http, apt_https, apt_http",
@@ -826,7 +825,7 @@ class TestProcessConfig:
             ),
         ],
     )
-    @mock.patch("uaclient.util.validate_proxy")
+    @mock.patch("uaclient.http.validate_proxy")
     @mock.patch("uaclient.livepatch.get_config_option_value")
     @mock.patch("uaclient.livepatch.configure_livepatch_proxy")
     @mock.patch(
@@ -834,14 +833,14 @@ class TestProcessConfig:
     )
     @mock.patch("uaclient.snap.get_config_option_value")
     @mock.patch("uaclient.snap.configure_snap_proxy")
-    @mock.patch("uaclient.snap.is_installed")
+    @mock.patch("uaclient.snap.is_snapd_installed")
     @mock.patch("uaclient.apt.setup_apt_proxy")
     @mock.patch("uaclient.config.state_files.user_config_file.write")
     def test_process_config(
         self,
         m_write,
         m_apt_configure_proxy,
-        m_snap_is_installed,
+        m_snap_is_snapd_installed,
         m_snap_configure_proxy,
         m_snap_get_config_option,
         m_livepatch_status,
@@ -850,7 +849,7 @@ class TestProcessConfig:
         m_validate_proxy,
         http_proxy,
         https_proxy,
-        snap_is_installed,
+        snap_is_snapd_installed,
         snap_http_val,
         snap_https_val,
         livepatch_enabled,
@@ -867,7 +866,7 @@ class TestProcessConfig:
         tmpdir,
         FakeConfig,
     ):
-        m_snap_is_installed.return_value = snap_is_installed
+        m_snap_is_snapd_installed.return_value = snap_is_snapd_installed
         m_snap_get_config_option.side_effect = [snap_http_val, snap_https_val]
         m_livepatch_status.return_value = (
             (ApplicationStatus.ENABLED, None)
@@ -909,20 +908,20 @@ class TestProcessConfig:
 
             assert [
                 mock.call(
-                    "http", global_http, util.PROXY_VALIDATION_APT_HTTP_URL
+                    "http", global_http, http.PROXY_VALIDATION_APT_HTTP_URL
                 ),
                 mock.call(
-                    "https", global_https, util.PROXY_VALIDATION_APT_HTTPS_URL
+                    "https", global_https, http.PROXY_VALIDATION_APT_HTTPS_URL
                 ),
-                mock.call("http", ua_http, util.PROXY_VALIDATION_APT_HTTP_URL),
+                mock.call("http", ua_http, http.PROXY_VALIDATION_APT_HTTP_URL),
                 mock.call(
-                    "https", ua_https, util.PROXY_VALIDATION_APT_HTTPS_URL
+                    "https", ua_https, http.PROXY_VALIDATION_APT_HTTPS_URL
                 ),
                 mock.call(
-                    "http", http_proxy, util.PROXY_VALIDATION_SNAP_HTTP_URL
+                    "http", http_proxy, http.PROXY_VALIDATION_SNAP_HTTP_URL
                 ),
                 mock.call(
-                    "https", https_proxy, util.PROXY_VALIDATION_SNAP_HTTPS_URL
+                    "https", https_proxy, http.PROXY_VALIDATION_SNAP_HTTPS_URL
                 ),
             ] == m_validate_proxy.call_args_list
 
@@ -939,7 +938,7 @@ class TestProcessConfig:
             else:
                 assert [] == m_apt_configure_proxy.call_args_list
 
-            if snap_is_installed:
+            if snap_is_snapd_installed:
                 assert [
                     mock.call(http_proxy, https_proxy)
                 ] == m_snap_configure_proxy.call_args_list
@@ -1135,7 +1134,6 @@ class TestParseConfig:
 
 
 class TestFeatures:
-    @pytest.mark.parametrize("caplog_text", [logging.WARNING], indirect=True)
     @pytest.mark.parametrize(
         "cfg_features,expected, warnings",
         (
@@ -1145,7 +1143,7 @@ class TestFeatures:
                 "badstring",
                 {},
                 "Unexpected uaclient.conf features value."
-                " Expected dict, but found badstring",
+                " Expected dict, but found %s",
             ),
             ({"feature1": "value1"}, {"feature1": "value1"}, None),
             (
@@ -1155,14 +1153,22 @@ class TestFeatures:
             ),
         ),
     )
+    @mock.patch("uaclient.config.LOG.warning")
     def test_features_are_a_property_of_uaconfig(
-        self, cfg_features, expected, warnings, caplog_text, FakeConfig
+        self,
+        m_log_warning,
+        cfg_features,
+        expected,
+        warnings,
+        FakeConfig,
     ):
         user_cfg = {"features": cfg_features}
         cfg = FakeConfig(cfg_overrides=user_cfg)
         assert expected == cfg.features
         if warnings:
-            assert warnings in caplog_text()
+            assert [
+                mock.call(warnings, cfg_features)
+            ] == m_log_warning.call_args_list
 
 
 class TestMachineTokenOverlay:
