@@ -8,7 +8,7 @@ import uuid
 import mock
 import pytest
 
-from uaclient import exceptions, messages, system
+from uaclient import apt, exceptions, messages, system
 
 
 class TestGetKernelInfo:
@@ -354,6 +354,64 @@ class TestGetDpkgArch:
         ]
 
 
+class TestGetVirtType:
+    @pytest.mark.parametrize(
+        [
+            "subp_side_effect",
+            "load_file_side_effect",
+            "expected",
+        ],
+        [
+            ([("", "")], None, ""),
+            ([("lxc\n", "")], None, "lxc"),
+            ([("lxc\n", "anything")], None, "lxc"),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                [""],
+                "",
+            ),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                ["line\nline\nlinedockerline\nline"],
+                "docker",
+            ),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                ["line\nline\nlinebuildkitline\nline"],
+                "docker",
+            ),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                ["line\nline\nlinebuildahline\nline"],
+                "podman",
+            ),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                ["line\nline\nline\nline"],
+                "",
+            ),
+            (
+                exceptions.ProcessExecutionError(cmd="", stdout="", stderr=""),
+                FileNotFoundError(),
+                "",
+            ),
+        ],
+    )
+    @mock.patch("uaclient.system.load_file")
+    @mock.patch("uaclient.system.subp")
+    def test_get_virt_type(
+        self,
+        m_subp,
+        m_load_file,
+        subp_side_effect,
+        load_file_side_effect,
+        expected,
+    ):
+        m_subp.side_effect = subp_side_effect
+        m_load_file.side_effect = load_file_side_effect
+        assert expected == system.get_virt_type.__wrapped__()
+
+
 class TestIsLTS:
     @pytest.mark.parametrize(
         "series, supported_esm, expected",
@@ -523,6 +581,90 @@ class TestIsContainer:
         assert calls == m_subp.call_args_list
 
 
+class TestIsDesktop:
+    @pytest.mark.parametrize(
+        ["installed_packages", "expected"],
+        [
+            ([], False),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="desktop-not-ubuntu", version="", arch=""
+                    ),
+                ],
+                False,
+            ),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="ubuntu-desktop", version="", arch=""
+                    ),
+                ],
+                True,
+            ),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="ubuntu-desktop-minimal", version="", arch=""
+                    ),
+                ],
+                True,
+            ),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="kubuntu-desktop", version="", arch=""
+                    ),
+                ],
+                True,
+            ),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="xubuntu-desktop", version="", arch=""
+                    ),
+                ],
+                True,
+            ),
+            (
+                [
+                    apt.InstalledAptPackage(
+                        name="not-desktop", version="", arch=""
+                    ),
+                    apt.InstalledAptPackage(
+                        name="lubuntu-desktop", version="", arch=""
+                    ),
+                ],
+                True,
+            ),
+        ],
+    )
+    @mock.patch("uaclient.apt.get_installed_packages")
+    def test_true_systemd_detect_virt_success(
+        self,
+        m_installed_packages,
+        installed_packages,
+        expected,
+    ):
+        m_installed_packages.return_value = installed_packages
+        assert expected == system.is_desktop.__wrapped__()
+
+
 class TestParseOSRelease:
     @pytest.mark.parametrize(
         "content, expected",
@@ -1145,37 +1287,48 @@ class TestSubp:
             )
         ] == m_popen.call_args_list
 
+    @mock.patch("subprocess.Popen")
+    def test_subp_no_pipe_stdouterr(
+        self,
+        m_popen,
+        _subp,
+    ):
+        mock_process = mock.MagicMock(returncode=0)
+        mock_process.communicate.return_value = (b"", b"")
+        m_popen.return_value = mock_process
 
-class TestGetSystemdJobState:
+        _subp(["fake"], pipe_stdouterr=False)
+
+        assert [
+            mock.call(
+                [b"fake"],
+                stdout=None,
+                stderr=None,
+                env=None,
+            )
+        ] == m_popen.call_args_list
+
+
+class TestIsSystemdServiceActive:
     @pytest.mark.parametrize(
-        "systemd_return,expected_return",
+        [
+            "subp_side_effect",
+            "expected_return",
+        ],
         (
-            ("active", True),
-            ("inactive", False),
-            ("", False),
-            (None, False),
-            ("test", False),
+            (None, True),
+            (exceptions.ProcessExecutionError("test"), False),
         ),
     )
     @mock.patch("uaclient.system.subp")
-    def test_get_systemd_job_state(
+    def test_is_systemd_unit_active(
         self,
-        subp,
-        systemd_return,
+        m_subp,
+        subp_side_effect,
         expected_return,
     ):
-        subp.return_value = (systemd_return, "")
-        assert expected_return == system.get_systemd_job_state(job_name="test")
-
-    @mock.patch("uaclient.system.subp")
-    def test_systemd_job_state_non_zero(
-        self,
-        subp,
-    ):
-        subp.side_effect = exceptions.ProcessExecutionError(
-            cmd="test", exit_code=3, stdout="inactive", stderr=""
-        )
-        assert False is system.get_systemd_job_state(job_name="test")
+        m_subp.side_effect = subp_side_effect
+        assert expected_return == system.is_systemd_unit_active("test")
 
 
 class TestGetCpuInfo:
@@ -1282,3 +1435,42 @@ class TestGetUserCacheDir:
         m_environ_get.return_value = xdg_cache_home
         m_expanduser.return_value = expanduser_result
         assert expected == system.get_user_cache_dir()
+
+
+class TestGetRebootRequiredPkgs:
+    @mock.patch("uaclient.system.load_file")
+    def test_when_no_reboot_required_file_is_found(self, m_load_file):
+        m_load_file.side_effect = FileNotFoundError()
+        assert system.get_reboot_required_pkgs() is None
+
+    @pytest.mark.parametrize(
+        "reboot_required_pkgs,expected_standard_pkgs,expected_kernel_pkgs",
+        (
+            ("", [], []),
+            ("pkg1\npkg2", ["pkg1", "pkg2"], []),
+            (
+                "pkg1\nlinux-image-pkg\npkg2\nlinux-base-pkg",
+                ["pkg1", "pkg2"],
+                ["linux-base-pkg", "linux-image-pkg"],
+            ),
+            (
+                "linux-image-pkg\nlinux-base-pkg",
+                [],
+                ["linux-base-pkg", "linux-image-pkg"],
+            ),
+        ),
+    )
+    @mock.patch("uaclient.system.load_file")
+    def test_reboot_required_pkgs(
+        self,
+        m_load_file,
+        reboot_required_pkgs,
+        expected_standard_pkgs,
+        expected_kernel_pkgs,
+    ):
+        m_load_file.return_value = reboot_required_pkgs
+        reboot_required_pkgs = system.get_reboot_required_pkgs()
+
+        assert reboot_required_pkgs is not None
+        assert expected_standard_pkgs == reboot_required_pkgs.standard_packages
+        assert expected_kernel_pkgs == reboot_required_pkgs.kernel_packages
